summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorGiuseppe Bilotta <giuseppe.bilotta@gmail.com>2007-09-18 06:15:52 +0000
committerGiuseppe Bilotta <giuseppe.bilotta@gmail.com>2007-09-18 06:15:52 +0000
commitb1debac35f5e45545066da07027ddaaf6c9faca7 (patch)
treeff21cb378d6fc299c5067c30ef6b397877eb26c2 /lib
parent0079ca3ac1adb77e4ddc9ebd34149c60d73b7529 (diff)
basics: it's @bot.myself, not just myself
Diffstat (limited to 'lib')
-rw-r--r--lib/rbot/core/basics.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/rbot/core/basics.rb b/lib/rbot/core/basics.rb
index e4c74f98..4b5ab7d3 100644
--- a/lib/rbot/core/basics.rb
+++ b/lib/rbot/core/basics.rb
@@ -106,7 +106,7 @@ class BasicsModule < CoreBotModule
when "restart"
_("restart => completely stop and restart the bot (including reconnect)")
when "join"
- _("join <channel> [<key>] => join channel <channel> with secret key <key> if specified. #{myself} also responds to invites if you have the required access level")
+ _("join <channel> [<key>] => join channel <channel> with secret key <key> if specified. #{@bot.myself} also responds to invites if you have the required access level")
when "part"
_("part <channel> => part channel <channel>")
when "hide"
@@ -126,9 +126,9 @@ class BasicsModule < CoreBotModule
when "mode"
_("mode <channel> <mode> <nicks> => set channel modes for <nicks> on <channel> to <mode>")
# when "botsnack"
# return "botsnack => reward #{myself} for being good"
# when "hello"
- # return "hello|hi|hey|yo [#{myself}] => greet the bot"
+ # return "hello|hi|hey|yo [#{@bot.myself}] => greet the bot"
else
_("%{name}: quit, restart, join, part, hide, save, nick, say, action, topic, quiet, talk, ping, mode") % {:name=>name}
#, botsnack, hello
@@ -126,9 +126,9 @@ class BasicsModule < CoreBotModule
_("mode <channel> <mode> <nicks> => set channel modes for <nicks> on <channel> to <mode>")
# when "botsnack"
- # return "botsnack => reward #{myself} for being good"
+ # return "botsnack => reward #{@bot.myself} for being good"
# when "hello"